#ifndef NT2_INCLUDE_CONSTANTS_MAXINIT_HPP_INCLUDED
#define NT2_INCLUDE_CONSTANTS_MAXINIT_HPP_INCLUDED

#include <nt2/constant/include/constants/maxinit.hpp>

#endif
